@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1993-2002 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1993-2008 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -30,19 +30,19 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_DMA_IN_USE               0x00000002
 #define RM_ERR_DMA_MEM_NOT_LOCKED       0x00000003
 #define RM_ERR_DMA_MEM_NOT_UNLOCKED     0x00000004
-#define RM_ERR_FIFO_BAD_ACCESS          0x00000005
-#define RM_ERR_ILLEGAL_ACTION           0x00000006
-#define RM_ERR_ILLEGAL_ADDRESS          0x00000007
-#define RM_ERR_ILLEGAL_OBJECT           0x00000008
-#define RM_ERR_INSERT_DUPLICATE_NAME    0x00000009
-#define RM_ERR_INSUFFICIENT_RESOURCES   0x0000000A
-#define RM_ERR_INVALID_ADDRESS          0x0000000B
-#define RM_ERR_INVALID_ARGUMENT         0x0000000C
-#define RM_ERR_INVALID_BASE             0x0000000D
-#define RM_ERR_INVALID_CHANNEL          0x0000000E
-#define RM_ERR_INVALID_CLASS            0x0000000F
-#define RM_ERR_INVALID_CLIENT           0x00000010
-#define RM_ERR_INVALID_COLOR_FORMAT     0x00000011
+#define RM_ERR_DUAL_LINK_INUSE          0x00000005
+#define RM_ERR_FIFO_BAD_ACCESS          0x00000006
+#define RM_ERR_GPU_NOT_FULL_POWER       0x00000007
+#define RM_ERR_ILLEGAL_ACTION           0x00000008
+#define RM_ERR_ILLEGAL_OBJECT           0x00000009
+#define RM_ERR_INSERT_DUPLICATE_NAME    0x0000000A
+#define RM_ERR_INSUFFICIENT_RESOURCES   0x0000000B
+#define RM_ERR_INVALID_ADDRESS          0x0000000C
+#define RM_ERR_INVALID_ARGUMENT         0x0000000D
+#define RM_ERR_INVALID_BASE             0x0000000E
+#define RM_ERR_INVALID_CHANNEL          0x0000000F
+#define RM_ERR_INVALID_CLASS            0x00000010
+#define RM_ERR_INVALID_CLIENT           0x00000011
 #define RM_ERR_INVALID_COMMAND          0x00000012
 #define RM_ERR_INVALID_DATA             0x00000013
 #define RM_ERR_INVALID_DEVICE           0x00000014
@@ -63,12 +63,12 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_INVALID_OFFSET           0x00000023
 #define RM_ERR_INVALID_OWNER            0x00000024
 #define RM_ERR_INVALID_PARAM_STRUCT     0x00000025
-#define RM_ERR_INVALID_READ             0x00000026
-#define RM_ERR_INVALID_START_LENGTH     0x00000027
+#define RM_ERR_INVALID_POINTER          0x00000026
+#define RM_ERR_INVALID_READ             0x00000027
 #define RM_ERR_INVALID_STATE            0x00000028
 #define RM_ERR_INVALID_WRITE            0x00000029
 #define RM_ERR_INVALID_XLATE            0x0000002A
-#define RM_ERR_MEM_NOT_FREED            0x0000002B
+#define RM_ERR_IRQ_NOT_FIRING           0x0000002B
 #define RM_ERR_MULTIPLE_MEMORY_TYPES    0x0000002C
 #define RM_ERR_NO_FREE_FIFOS            0x0000002D
 #define RM_ERR_NO_FREE_MEM              0x0000002E
@@ -77,35 +77,34 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_OBJECT_TYPE_MISMATCH     0x00000031
 #define RM_ERR_OPERATING_SYSTEM         0x00000032
 #define RM_ERR_OTHER_DEVICE_FOUND       0x00000033
-#define RM_ERR_OUT_OF_TIMER_CALLBACKS   0x00000034
+#define RM_ERR_CALLBACK_NOT_SCHEDULED   0x00000034
 #define RM_ERR_PAGE_TABLE_NOT_AVAIL     0x00000035
 #define RM_ERR_PROTECTION_FAULT         0x00000036
 #define RM_ERR_STATE_IN_USE             0x00000037
 #define RM_ERR_TIMEOUT                  0x00000038
-#define RM_ERR_GPU_NOT_FULL_POWER       0x00000039
-#define RM_ERR_IRQ_NOT_FIRING           0x0000003A
-
-/* Old names -- to be replaced by "INVALID" names */
-#define RM_ERR_BAD_ADDRESS              RM_ERR_INVALID_ADDRESS
-#define RM_ERR_BAD_ARGUMENT             RM_ERR_INVALID_ARGUMENT
-#define RM_ERR_BAD_BASE                 RM_ERR_INVALID_BASE
-#define RM_ERR_BAD_CLASS                RM_ERR_INVALID_CLASS
-#define RM_ERR_BAD_CLIENT               RM_ERR_INVALID_CLIENT
-#define RM_ERR_BAD_DMA_SPECIFIER        RM_ERR_INVALID_DMA_SPECIFIER
-#define RM_ERR_BAD_FLAGS                RM_ERR_INVALID_FLAGS
-#define RM_ERR_BAD_INDEX                RM_ERR_INVALID_INDEX
-#define RM_ERR_BAD_LIMIT                RM_ERR_INVALID_LIMIT
-#define RM_ERR_BAD_OBJECT               RM_ERR_INVALID_OBJECT
-#define RM_ERR_BAD_OBJECT_BUFFER        RM_ERR_INVALID_OBJECT_BUFFER
-#define RM_ERR_BAD_OBJECT_ERROR         RM_ERR_INVALID_OBJECT_ERROR
-#define RM_ERR_BAD_OBJECT_HANDLE        RM_ERR_INVALID_OBJECT_HANDLE
-#define RM_ERR_BAD_OBJECT_OLD           RM_ERR_INVALID_OBJECT_OLD
-#define RM_ERR_BAD_OBJECT_PARENT        RM_ERR_INVALID_OBJECT_PARENT
-#define RM_ERR_BAD_OFFSET               RM_ERR_INVALID_OFFSET
-#define RM_ERR_BAD_PARAM_STRUCT         RM_ERR_INVALID_PARAM_STRUCT
-#define RM_ERR_BAD_READ                 RM_ERR_INVALID_READ
-#define RM_ERR_BAD_WRITE                RM_ERR_INVALID_WRITE
+#define RM_ERR_BUFFER_TOO_SMALL         0x00000039
+#define RM_ERR_NO_SUCH_DOMAIN           0x0000003A
+#define RM_ERR_I2C_ERROR                0x0000003B
+#define RM_ERR_FREQ_NOT_SUPPORTED       0x0000003C
+#define RM_ERR_INVALID_REQUEST          0x0000003D
+#define RM_ERR_MORE_PROCESSING_REQUIRED 0x0000003E
+#define RM_ERR_MISSING_TABLE_ENTRY      0x0000003F
+#define RM_ERR_NO_INTR_PENDING          0x00000040
+#define RM_ERR_INSUFFICIENT_PERMISSIONS 0x00000041
+#define RM_ERR_TIMEOUT_RETRY            0x00000042
+#define RM_ERR_NOT_READY                0x00000043
+#define RM_ERR_BROKEN_FB                0x00000044
+#define RM_ERR_GPU_IS_LOST              0x00000045
+#define RM_ERR_GPU_IN_FULLCHIP_RESET    0x00000046
+#define RM_ERR_INVALID_LOCK_STATE       0x00000047
+#define RM_ERR_NOT_ENOUGH_POWER         0x00000048
+#define RM_ERR_REJECTED_VBIOS           0x00000049
+#define RM_ERR_MEMORY_TRAINING_FAILED   0X0000004A
+#define RM_ERR_I2C_SPEED_TOO_HIGH       0X00000050
+#define RM_ERR_BUSY_RETRY               0X00000051
 
+// Warnings:
 #define RM_WARN_NULL_OBJECT             0x00000100
+#define RM_WARN_INCORRECT_PERFMON_DATA  0x00000101
 
 #endif /* _RMRETVAL_H_ */
